@@ -18,8 +18,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -40,6 +40,12 @@
 #include "persist-file.h"
 #include "editor-control-factory.h"
 
+#include <glib/gstdio.h>
+
+#ifndef O_BINARY
+#define O_BINARY 0
+#endif
+
 static BonoboObjectClass *gtk_html_persist_file_parent_class;
 
 static void impl_save (PortableServer_Servant servant, const CORBA_char *path, CORBA_Environment * ev);
@@ -144,7 +150,7 @@ impl_load (PortableServer_Servant servant, const CORBA_char *path, CORBA_Environ
 	gboolean was_editable;
 	int fd;
 
-	fd = open (path, O_RDONLY);
+	fd = g_open (path, O_RDONLY | O_BINARY, 0);
 	if (fd == -1)
 		return;
 
@@ -215,7 +221,7 @@ impl_save (PortableServer_Servant servant, const CORBA_char *path, CORBA_Environ
 	GtkHTMLPersistFile *file = GTK_HTML_PERSIST_FILE (bonobo_object_from_servant (servant));
 	int fd;
 
-	fd = open (path, O_WRONLY | O_CREAT | O_TRUNC, 0666);
+	fd = g_open (path, O_WRONLY | O_CREAT | O_TRUNC | O_BINARY, 0666);
 
 	if (fd == -1)
 		return;
