@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -42,6 +42,7 @@
 #include "htmlimage.h"
 #include "htmltable.h"
 #include "htmlsettings.h"
+#include "gtkhtml-private.h"
 
 #include "properties.h"
 #include "table.h"
@@ -100,11 +101,8 @@ changed_bg_pixmap (GtkWidget *w, GtkHTMLEditTableProperties *d)
 		return;
 
 	html_cursor_forward (d->cd->html->engine->cursor, d->cd->html->engine);
-	file = gtk_entry_get_text (GTK_ENTRY (w));
-	if (file && *file)
-		url = g_strconcat ("file://", file, NULL);
-	else
-		url = NULL;
+	file = (const char *) gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (w));
+	url = gtk_html_filename_to_uri (file);
 	html_engine_table_set_bg_pixmap (d->cd->html->engine, d->table, url);
 	g_free (url);
 }
@@ -140,33 +138,35 @@ changed_border (GtkWidget *w, GtkHTMLEditTableProperties *d)
 }
 
 static void
-changed_align (GtkWidget *w, GtkHTMLEditTableProperties *d)
+changed_align (GtkComboBox *combo_box, GtkHTMLEditTableProperties *d)
 {
+	HTMLHAlignType align = HTML_HALIGN_LEFT;
+
 	if (d->disable_change || !editor_has_html_object (d->cd, HTML_OBJECT (d->table)))
 		return;
 
+	align += gtk_combo_box_get_active (combo_box);
 	html_cursor_forward (d->cd->html->engine->cursor, d->cd->html->engine);
-	html_engine_table_set_align (d->cd->html->engine, d->table,
-					     g_list_index (GTK_MENU_SHELL (w)->children, gtk_menu_get_active (GTK_MENU (w))) + HTML_HALIGN_LEFT);
+	html_engine_table_set_align (d->cd->html->engine, d->table, align);
 }
 
 static void
 set_width (GtkHTMLEditTableProperties *d)
 {
-	GtkWidget *menu;
-
 	if (d->disable_change || !editor_has_html_object (d->cd, HTML_OBJECT (d->table)))
 		return;
 
 	html_cursor_forward (d->cd->html->engine->cursor, d->cd->html->engine);
-	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (d->option_width));
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (d->check_width))) {
-		if (g_list_index (GTK_MENU_SHELL (menu)->children, gtk_menu_get_active (GTK_MENU (menu))))
-			html_engine_table_set_width (d->cd->html->engine, d->table, gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (d->spin_width)), TRUE);
-		else
-			html_engine_table_set_width (d->cd->html->engine, d->table, gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (d->spin_width)), FALSE);
-	} else
-			html_engine_table_set_width (d->cd->html->engine, d->table, 0, FALSE);
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (d->check_width)))
+		html_engine_table_set_width (
+			d->cd->html->engine, d->table,
+			gtk_spin_button_get_value_as_int (
+				GTK_SPIN_BUTTON (d->spin_width)),
+			gtk_combo_box_get_active (
+				GTK_COMBO_BOX (d->option_width)) > 0);
+	else
+		html_engine_table_set_width (
+			d->cd->html->engine, d->table, 0, FALSE);
 }
 
 static void
@@ -220,20 +220,16 @@ table_widget (GtkHTMLEditTableProperties *d)
 {
 	GtkWidget *table_page;
 	GladeXML *xml;
+	gchar *filename;
 
-	xml = glade_xml_new (GLADE_DATADIR "/gtkhtml-editor-properties.glade", "table_page", GETTEXT_PACKAGE);
+	filename = g_build_filename (GLADE_DATADIR, "gtkhtml-editor-properties.glade", NULL);
+	xml = glade_xml_new (filename, "table_page", GETTEXT_PACKAGE);
+	g_free (filename);
 	if (!xml)
 		g_error (_("Could not load glade file."));
 
 	table_page = glade_xml_get_widget (xml, "table_page");
 
-	gtk_box_pack_start (GTK_BOX (glade_xml_get_widget (xml, "table_rows_hbox")),
-			    gtk_image_new_from_file (ICONDIR "/table-row-16.png"),
-			    FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (glade_xml_get_widget (xml, "table_cols_hbox")),
-			    gtk_image_new_from_file (ICONDIR "/table-column-16.png"),
-			    FALSE, FALSE, 0);
-
 	d->combo_bg_color = gi_color_combo_new (NULL, _("Transparent"), NULL,
 					     color_group_fetch ("table_bg_color", d->cd));
         gi_color_combo_box_set_preview_relief (GI_COLOR_COMBO (d->combo_bg_color), GTK_RELIEF_NORMAL); \
@@ -241,8 +237,8 @@ table_widget (GtkHTMLEditTableProperties *d)
 	gtk_box_pack_start (GTK_BOX (glade_xml_get_widget (xml, "bg_color_hbox")), d->combo_bg_color, FALSE, FALSE, 0);
 
 	d->entry_bg_pixmap = glade_xml_get_widget (xml, "entry_table_bg_pixmap");
-	g_signal_connect (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (d->entry_bg_pixmap)),
-			  "changed", G_CALLBACK (changed_bg_pixmap), d);
+	g_signal_connect (GTK_FILE_CHOOSER_BUTTON (d->entry_bg_pixmap),
+			  "selection-changed", G_CALLBACK (changed_bg_pixmap), d);
 
 	d->spin_spacing = glade_xml_get_widget (xml, "spin_spacing");
 	g_signal_connect (d->spin_spacing, "value_changed", G_CALLBACK (changed_spacing), d);
@@ -255,8 +251,7 @@ table_widget (GtkHTMLEditTableProperties *d)
 	UPPER_FIX (border);
 
 	d->option_align = glade_xml_get_widget (xml, "option_table_align");
-	g_signal_connect (gtk_option_menu_get_menu (GTK_OPTION_MENU (d->option_align)), "selection-done",
-			  G_CALLBACK (changed_align), d);
+	g_signal_connect (d->option_align, "changed", G_CALLBACK (changed_align), d);
 
 	d->spin_width   = glade_xml_get_widget (xml, "spin_table_width");
 	g_signal_connect (d->spin_width, "value_changed", G_CALLBACK (changed_width), d);
@@ -264,8 +259,7 @@ table_widget (GtkHTMLEditTableProperties *d)
 	d->check_width  = glade_xml_get_widget (xml, "check_table_width");
 	g_signal_connect (d->check_width, "toggled", G_CALLBACK (set_has_width), d);
 	d->option_width = glade_xml_get_widget (xml, "option_table_width");
-	g_signal_connect (gtk_option_menu_get_menu (GTK_OPTION_MENU (d->option_width)), "selection-done",
-			  G_CALLBACK (changed_width_percent), d);
+	g_signal_connect (d->option_width, "changed", G_CALLBACK (changed_width_percent), d);
 
 	d->spin_cols = glade_xml_get_widget (xml, "spin_table_columns");
 	g_signal_connect (d->spin_cols, "value_changed", G_CALLBACK (changed_cols), d);
@@ -275,7 +269,7 @@ table_widget (GtkHTMLEditTableProperties *d)
 	UPPER_FIX (rows);
 
 	gtk_widget_show_all (table_page);
-	gnome_pixmap_entry_set_preview (GNOME_PIXMAP_ENTRY (d->entry_bg_pixmap), FALSE);
+	gtk_file_chooser_set_preview_widget_active (GTK_FILE_CHOOSER (d->entry_bg_pixmap), FALSE);
 
 	return table_page;
 }
@@ -294,15 +288,11 @@ set_ui (GtkHTMLEditTableProperties *d)
 		gi_color_combo_set_color (GI_COLOR_COMBO (d->combo_bg_color), d->table->bgColor);
 
 		if (d->table->bgPixmap) {
-			int off = 0;
+			gchar *filename = gtk_html_filename_from_uri (d->table->bgPixmap->url);
 
-			if (!strncasecmp ("file://", d->table->bgPixmap->url, 7))
-				off = 7;
-			else if (!strncasecmp ("file:", d->table->bgPixmap->url, 5))
-				off = 5;
-
-			gtk_entry_set_text (GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (d->entry_bg_pixmap))),
-					    d->table->bgPixmap->url + off);
+			gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (d->entry_bg_pixmap),
+					    filename);
+			g_free (filename);
 		}
 
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (d->spin_spacing), d->table->spacing);
@@ -313,7 +303,9 @@ set_ui (GtkHTMLEditTableProperties *d)
 		halign = HTML_CLUE (HTML_OBJECT (d->table)->parent)->halign;
 		if (halign == HTML_HALIGN_NONE)
 			halign = HTML_HALIGN_LEFT;
-		gtk_option_menu_set_history (GTK_OPTION_MENU (d->option_align), halign - HTML_HALIGN_LEFT);
+		gtk_combo_box_set_active (
+			GTK_COMBO_BOX (d->option_align),
+			halign - HTML_HALIGN_LEFT);
 
 		if (HTML_OBJECT (d->table)->percent) {
 			width = HTML_OBJECT (d->table)->percent;
@@ -328,10 +320,9 @@ set_ui (GtkHTMLEditTableProperties *d)
 
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (d->check_width), has_width);
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (d->spin_width),  width);
-		if (percent)
-			gtk_option_menu_set_history (GTK_OPTION_MENU (d->option_width), 1);
-		else
-			gtk_option_menu_set_history (GTK_OPTION_MENU (d->option_width), 0);
+		gtk_combo_box_set_active (
+			GTK_COMBO_BOX (d->option_width),
+			percent ? 1 : 0);
 
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (d->spin_cols),  d->table->totalCols);
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (d->spin_rows),  d->table->totalRows);
